searchData={"items":[{"type":"module","title":"EctoUnixTimestamp","doc":"An Ecto type for datetime fields that are cast as **Unix timestamps**.\n\nThis type is useful when the data you're casting comes in as a Unix timestamp. In those\ncases, the built-in Ecto types `:utc_datetime`, `:utc_datetime_usec`, `:naive_datetime`,\nand `:naive_datetime_usec` work for *storing* the data but not for *casting*. You're forced\nto pre-parse the parameters that contain the Unix timestamps and convert them into\n`DateTime` or `NaiveDateTime` structs before passing them to Ecto, which somewhat defeats\nthe purpose of Ecto casting for those fields. This nimble library solves exactly this issue.\n\n> ##","ref":"EctoUnixTimestamp.html"},{"type":"module","title":"Casting Datetimes {: .info} - EctoUnixTimestamp","doc":">\n> When casting a field of type `EctoUnixTimestamp`, the value of the field can also be a\n> `DateTime` or `NaiveDateTime` struct. In that case, the value is passed through as-is.","ref":"EctoUnixTimestamp.html#module-casting-datetimes-info"},{"type":"module","title":"Usage - EctoUnixTimestamp","doc":"Use this Ecto type in your schemas. You'll have to choose the **precision** of the Unix\ntimestamp, and the underlying database data type you want to *store* the data as.\n\n    defmodule User do\n      use Ecto.Schema\n\n      schema \"users\" do\n        field :created_at, EctoUnixTimestamp, unit: :second, underlying_type: :utc_datetime\n      end\n    end\n\nOnce you have this, you can cast Unix timestamps:\n\n    import Ecto.Changeset\n\n    changeset = cast(%User{}, %{created_at: 1672563600}, [:created_at])\n\n    fetch_field!(changeset, :created_at)\n    #=> ~U[2023-01-01 09:00:00Z]","ref":"EctoUnixTimestamp.html#module-usage"},{"type":"module","title":"Options - EctoUnixTimestamp","doc":"A `field` whose type is `EctoUnixTimestamp` accepts the following options:\n\n  * `:unit` - The precision of the Unix timestamp. Must be one of `:second`,\n    `:millisecond`, `:microsecond`, or `:nanosecond`. This option is **required**.\n\n  * `:underlying_type` - The underlying Ecto type to use for storing the data.\n    This option is **required**. It can be one of the native datetime types, that is,\n    `:utc_datetime`, `:utc_datetime_usec`, `:naive_datetime`, or\n    `:naive_datetime_usec`.\n\n  * `:accept_strings` - A boolean that indicates whether the type should accept strings\n    as input. If `true`, the type will attempt to parse strings as integers. If `false`,\n    the type will only accept integers and `DateTime`/`NaiveDateTime` structs. Defaults to\n    `true`. *Available since v1.0.0*.","ref":"EctoUnixTimestamp.html#module-options"},{"type":"module","title":"Examples of Casting - EctoUnixTimestamp","doc":"iex> type = Ecto.ParameterizedType.init(EctoUnixTimestamp, unit: :millisecond, underlying_type: :utc_datetime)\n    iex> Ecto.Type.cast(type, 1706818415865)\n    {:ok, ~U[2024-02-01 20:13:35.865Z]}\n\n    iex> type = Ecto.ParameterizedType.init(EctoUnixTimestamp, unit: :second, underlying_type: :naive_datetime)\n    iex> Ecto.Type.cast(type, 1706818415)\n    {:ok, ~N[2024-02-01 20:13:35Z]}\n\nWith a `DateTime` or `NaiveDateTime` struct:\n\n    iex> type = Ecto.ParameterizedType.init(EctoUnixTimestamp, unit: :second, underlying_type: :naive_datetime)\n    iex> Ecto.Type.cast(type, ~N[2024-02-01 20:13:35Z])\n    {:ok, ~N[2024-02-01 20:13:35Z]}\n\n    iex> type = Ecto.ParameterizedType.init(EctoUnixTimestamp, unit: :second, underlying_type: :utc_datetime_usec)\n    iex> Ecto.Type.cast(type, ~U[2024-02-01 20:13:35.846393Z])\n    {:ok, ~U[2024-02-01 20:13:35.846393Z]}\n\nWith a string:\n\n    iex> type = Ecto.ParameterizedType.init(EctoUnixTimestamp, unit: :millisecond, underlying_type: :utc_datetime, accept_strings: true)\n    iex> Ecto.Type.cast(type, \"1706818415866\")\n    {:ok, ~U[2024-02-01 20:13:35.866Z]}\n\n`nil` is always valid, as with any other Ecto type:\n\n    iex> type = Ecto.ParameterizedType.init(EctoUnixTimestamp, unit: :second, underlying_type: :naive_datetime)\n    iex> Ecto.Type.cast(type, nil)\n    {:ok, nil}","ref":"EctoUnixTimestamp.html#module-examples-of-casting"},{"type":"type","title":"EctoUnixTimestamp.t/0","doc":"Type for a field of type `EctoUnixTimestamp`.","ref":"EctoUnixTimestamp.html#t:t/0"}],"content_type":"text/markdown"}